/* wizard-source.c generated by valac 0.24.0.112-bbf5, the Vala compiler
 * generated from wizard-source.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <osinfo/osinfo.h>
#include <glib/gi18n-lib.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_SOURCE_PAGE (boxes_source_page_get_type ())

#define BOXES_TYPE_WIZARD_SCROLLED (boxes_wizard_scrolled_get_type ())
#define BOXES_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled))
#define BOXES_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))
#define BOXES_IS_WIZARD_SCROLLED(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_IS_WIZARD_SCROLLED_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SCROLLED))
#define BOXES_WIZARD_SCROLLED_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledClass))

typedef struct _BoxesWizardScrolled BoxesWizardScrolled;
typedef struct _BoxesWizardScrolledClass BoxesWizardScrolledClass;
typedef struct _BoxesWizardScrolledPrivate BoxesWizardScrolledPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_list_free0(var) ((var == NULL) ? NULL : (var = (g_list_free (var), NULL)))

#define BOXES_TYPE_WIZARD_MEDIA_ENTRY (boxes_wizard_media_entry_get_type ())
#define BOXES_WIZARD_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntry))
#define BOXES_WIZARD_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryClass))
#define BOXES_IS_WIZARD_MEDIA_ENTRY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY))
#define BOXES_IS_WIZARD_MEDIA_ENTRY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_MEDIA_ENTRY))
#define BOXES_WIZARD_MEDIA_ENTRY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryClass))

typedef struct _BoxesWizardMediaEntry BoxesWizardMediaEntry;
typedef struct _BoxesWizardMediaEntryClass BoxesWizardMediaEntryClass;
typedef struct _BoxesWizardMediaEntryPrivate BoxesWizardMediaEntryPrivate;

#define BOXES_TYPE_INSTALLER_MEDIA (boxes_installer_media_get_type ())
#define BOXES_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMedia))
#define BOXES_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))
#define BOXES_IS_INSTALLER_MEDIA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_IS_INSTALLER_MEDIA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_INSTALLER_MEDIA))
#define BOXES_INSTALLER_MEDIA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_INSTALLER_MEDIA, BoxesInstallerMediaClass))

typedef struct _BoxesInstallerMedia BoxesInstallerMedia;
typedef struct _BoxesInstallerMediaClass BoxesInstallerMediaClass;
typedef struct _BoxesInstallerMediaPrivate BoxesInstallerMediaPrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;
#define _g_free0(var) (var = (g_free (var), NULL))

#define BOXES_TYPE_WIZARD_SOURCE (boxes_wizard_source_get_type ())
#define BOXES_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource))
#define BOXES_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))
#define BOXES_IS_WIZARD_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_IS_WIZARD_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD_SOURCE))
#define BOXES_WIZARD_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourceClass))

typedef struct _BoxesWizardSource BoxesWizardSource;
typedef struct _BoxesWizardSourceClass BoxesWizardSourceClass;
typedef struct _BoxesWizardSourcePrivate BoxesWizardSourcePrivate;

#define BOXES_TYPE_MEDIA_MANAGER (boxes_media_manager_get_type ())
#define BOXES_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManager))
#define BOXES_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))
#define BOXES_IS_MEDIA_MANAGER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_IS_MEDIA_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MEDIA_MANAGER))
#define BOXES_MEDIA_MANAGER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MEDIA_MANAGER, BoxesMediaManagerClass))

typedef struct _BoxesMediaManager BoxesMediaManager;
typedef struct _BoxesMediaManagerClass BoxesMediaManagerClass;

#define BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER (boxes_libvirt_system_importer_get_type ())
#define BOXES_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporter))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_IS_LIBVIRT_SYSTEM_IMPORTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER))
#define BOXES_LIBVIRT_SYSTEM_IMPORTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, BoxesLibvirtSystemImporterClass))

typedef struct _BoxesLibvirtSystemImporter BoxesLibvirtSystemImporter;
typedef struct _BoxesLibvirtSystemImporterClass BoxesLibvirtSystemImporterClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _BoxesWizardSourceAddMediaEntriesData BoxesWizardSourceAddMediaEntriesData;
typedef struct _Block69Data Block69Data;
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;

typedef enum  {
	BOXES_SOURCE_PAGE_MAIN,
	BOXES_SOURCE_PAGE_URL,
	BOXES_SOURCE_PAGE_LAST
} BoxesSourcePage;

typedef gboolean (*ClickedFunc) (void* user_data);
struct _BoxesWizardScrolled {
	GtkScrolledWindow parent_instance;
	BoxesWizardScrolledPrivate * priv;
	GtkBox* vbox;
};

struct _BoxesWizardScrolledClass {
	GtkScrolledWindowClass parent_class;
};

struct _BoxesWizardScrolledPrivate {
	gint num_visible;
};

struct _BoxesWizardMediaEntry {
	GtkButton parent_instance;
	BoxesWizardMediaEntryPrivate * priv;
	BoxesInstallerMedia* media;
};

struct _BoxesWizardMediaEntryClass {
	GtkButtonClass parent_class;
};

struct _BoxesWizardMediaEntryPrivate {
	GtkImage* media_image;
	GtkLabel* title_label;
	GtkLabel* details_label;
};

struct _BoxesInstallerMedia {
	GObject parent_instance;
	BoxesInstallerMediaPrivate * priv;
	OsinfoOs* os;
	OsinfoResources* resources;
	OsinfoMedia* os_media;
	gchar* label;
	gchar* device_file;
	gchar* mount_point;
	gboolean from_image;
};

struct _BoxesInstallerMediaClass {
	GObjectClass parent_class;
	void (*set_direct_boot_params) (BoxesInstallerMedia* self, GVirConfigDomainOs* os);
	void (*prepare) (BoxesInstallerMedia* self, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_);
	void (*prepare_for_installation) (BoxesInstallerMedia* self, const gchar* vm_name, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*prepare_for_installation_finish) (BoxesInstallerMedia* self, GAsyncResult* _res_, GError** error);
	void (*prepare_to_continue_installation) (BoxesInstallerMedia* self, const gchar* vm_name);
	void (*clean_up) (BoxesInstallerMedia* self);
	void (*clean_up_preparation_cache) (BoxesInstallerMedia* self);
	void (*setup_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*setup_post_install_domain_config) (BoxesInstallerMedia* self, GVirConfigDomain* domain);
	void (*populate_setup_box) (BoxesInstallerMedia* self, GtkBox* setup_box);
	GList* (*get_vm_properties) (BoxesInstallerMedia* self);
	BoxesVMCreator* (*get_vm_creator) (BoxesInstallerMedia* self);
	OsinfoDeviceList* (*get_supported_devices) (BoxesInstallerMedia* self);
	guint64 (*get_installed_size) (BoxesInstallerMedia* self);
	gboolean (*get_need_user_input_for_vm_creation) (BoxesInstallerMedia* self);
	gboolean (*get_ready_to_create) (BoxesInstallerMedia* self);
	gboolean (*get_live) (BoxesInstallerMedia* self);
	gchar* (*get_architecture) (BoxesInstallerMedia* self);
};

struct _BoxesWizardSource {
	GtkStack parent_instance;
	BoxesWizardSourcePrivate * priv;
	gboolean libvirt_sys_import;
	GtkEntry* url_entry;
	BoxesMediaManager* media_manager;
};

struct _BoxesWizardSourceClass {
	GtkStackClass parent_class;
};

struct _BoxesWizardSourcePrivate {
	GtkWidget* _selected;
	BoxesInstallerMedia* _install_media;
	BoxesLibvirtSystemImporter* _libvirt_sys_importer;
	GtkBox* main_vbox;
	BoxesWizardScrolled* media_scrolled;
	GtkLabel* url_description_label;
	GtkImage* url_image;
	GtkAlignment* url_entry_bin;
	GtkButton* select_file_button;
	GtkButton* libvirt_sys_import_button;
	GtkLabel* libvirt_sys_import_label;
	GtkBox* media_vbox;
	BoxesSourcePage _page;
};

struct _BoxesWizardSourceAddMediaEntriesData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizardSource* self;
	GList* medias;
	BoxesMediaManager* _tmp0_;
	GList* _tmp1_;
	GtkBox* _tmp2_;
	GList* _tmp3_;
	GList* child_collection;
	GList* child_it;
	GtkWidget* child;
	BoxesInstallerMedia* child_media;
	GtkWidget* _tmp4_;
	BoxesInstallerMedia* _tmp5_;
	BoxesInstallerMedia* _tmp6_;
	gboolean obsolete;
	GList* _tmp7_;
	GList* media_collection;
	GList* media_it;
	BoxesInstallerMedia* _tmp8_;
	BoxesInstallerMedia* media;
	BoxesInstallerMedia* _tmp9_;
	const gchar* _tmp10_;
	BoxesInstallerMedia* _tmp11_;
	const gchar* _tmp12_;
	gboolean _tmp13_;
	GtkBox* _tmp14_;
	GtkWidget* _tmp15_;
	GList* _tmp16_;
	GList* _vala1_media_collection;
	GList* _vala1_media_it;
	BoxesInstallerMedia* _tmp17_;
	BoxesInstallerMedia* _vala1_media;
	gboolean nouveau;
	GtkBox* _tmp18_;
	GList* _tmp19_;
	GList* _vala1_child_collection;
	GList* _vala1_child_it;
	GtkWidget* _vala1_child;
	BoxesInstallerMedia* _vala1_child_media;
	GtkWidget* _tmp20_;
	BoxesInstallerMedia* _tmp21_;
	BoxesInstallerMedia* _tmp22_;
	BoxesInstallerMedia* _tmp23_;
	const gchar* _tmp24_;
	BoxesInstallerMedia* _tmp25_;
	const gchar* _tmp26_;
	gboolean _tmp27_;
	BoxesInstallerMedia* _tmp28_;
	GtkBox* _tmp29_;
	GList* _tmp30_;
	GList* _tmp31_;
	guint _tmp32_;
	gboolean _tmp33_;
	BoxesWizardScrolled* _tmp34_;
};

struct _Block69Data {
	int _ref_count_;
	BoxesWizardSource* self;
	BoxesWizardMediaEntry* entry;
	BoxesInstallerMedia* media;
};

struct _BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesWizardSource* self;
	BoxesLibvirtSystemImporter* _tmp0_;
	BoxesLibvirtSystemImporter* _tmp1_;
	GError* _error_;
	GError* _tmp2_;
	const gchar* _tmp3_;
	GtkLabel* _tmp4_;
	BoxesLibvirtSystemImporter* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_;
	GtkButton* _tmp9_;
	GError * _inner_error_;
};


static gpointer boxes_wizard_scrolled_parent_class = NULL;
static gpointer boxes_wizard_media_entry_parent_class = NULL;
static gpointer boxes_wizard_source_parent_class = NULL;
extern BoxesAppWindow* boxes_app_window;

GType boxes_source_page_get_type (void) G_GNUC_CONST;
GType boxes_wizard_scrolled_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SCROLLED_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolledPrivate))
enum  {
	BOXES_WIZARD_SCROLLED_DUMMY_PROPERTY
};
void boxes_wizard_scrolled_setup (BoxesWizardScrolled* self, gint num_visible);
static void __lambda86_ (BoxesWizardScrolled* self);
static void ___lambda86__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda87_ (BoxesWizardScrolled* self);
static void ___lambda87__gtk_widget_show (GtkWidget* _sender, gpointer self);
static void __lambda88_ (BoxesWizardScrolled* self);
static void ___lambda88__gtk_widget_hide (GtkWidget* _sender, gpointer self);
static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height);
BoxesWizardScrolled* boxes_wizard_scrolled_new (void);
BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type);
static void boxes_wizard_scrolled_finalize (GObject* obj);
GType boxes_wizard_media_entry_get_type (void) G_GNUC_CONST;
GType boxes_installer_media_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_MEDIA_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntryPrivate))
enum  {
	BOXES_WIZARD_MEDIA_ENTRY_DUMMY_PROPERTY
};
BoxesWizardMediaEntry* boxes_wizard_media_entry_new (BoxesInstallerMedia* media);
BoxesWizardMediaEntry* boxes_wizard_media_entry_construct (GType object_type, BoxesInstallerMedia* media);
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static void boxes_wizard_media_entry_finalize (GObject* obj);
GType boxes_wizard_source_get_type (void) G_GNUC_CONST;
GType boxes_media_manager_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_system_importer_get_type (void) G_GNUC_CONST;
#define BOXES_WIZARD_SOURCE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSourcePrivate))
enum  {
	BOXES_WIZARD_SOURCE_DUMMY_PROPERTY,
	BOXES_WIZARD_SOURCE_SELECTED,
	BOXES_WIZARD_SOURCE_URI,
	BOXES_WIZARD_SOURCE_INSTALL_MEDIA,
	BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER,
	BOXES_WIZARD_SOURCE_PAGE
};
void boxes_wizard_source_cleanup (BoxesWizardSource* self);
static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value);
void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value);
void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value);
static void boxes_wizard_source_on_enter_url_button_clicked (BoxesWizardSource* self);
void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value);
static void _boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_on_url_back_button_clicked (BoxesWizardSource* self);
static void _boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name);
static void boxes_wizard_source_add_media_entries_data_free (gpointer _data);
static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_);
static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_);
void boxes_media_manager_list_installer_medias (BoxesMediaManager* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
GList* boxes_media_manager_list_installer_medias_finish (BoxesMediaManager* self, GAsyncResult* _res_);
static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static Block69Data* block69_data_ref (Block69Data* _data69_);
static void block69_data_unref (void * _userdata_);
static void __lambda89_ (Block69Data* _data69_);
static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media);
static void ___lambda89__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free (gpointer _data);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_finish (BoxesWizardSource* self, GAsyncResult* _res_);
static gboolean boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_);
void boxes_libvirt_system_importer_new (GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtSystemImporter* boxes_libvirt_system_importer_new_finish (GAsyncResult* _res_, GError** error);
void boxes_libvirt_system_importer_construct (GType object_type, GAsyncReadyCallback _callback_, gpointer _user_data_);
BoxesLibvirtSystemImporter* boxes_libvirt_system_importer_construct_finish (GAsyncResult* _res_, GError** error);
static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_wizard_source_set_libvirt_sys_importer (BoxesWizardSource* self, BoxesLibvirtSystemImporter* value);
BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self);
gchar* boxes_libvirt_system_importer_get_wizard_menu_label (BoxesLibvirtSystemImporter* self);
static void boxes_wizard_source_on_select_file_button_clicked (BoxesWizardSource* self);
GType boxes_app_window_get_type (void) G_GNUC_CONST;
static void _boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_wizard_source_on_libvirt_sys_import_button_clicked (BoxesWizardSource* self);
static void _boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
BoxesInstallerMedia* boxes_media_manager_create_installer_media_from_media (BoxesMediaManager* self, BoxesInstallerMedia* media, GError** error);
BoxesWizardSource* boxes_wizard_source_new (void);
BoxesWizardSource* boxes_wizard_source_construct (GType object_type);
GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self);
const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self);
BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self);
BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self);
static GObject * boxes_wizard_source_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
BoxesMediaManager* boxes_media_manager_get_instance (void);
void boxes_draw_as_css_box (GtkWidget* widget);
static void boxes_wizard_source_finalize (GObject* obj);
static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);

static const gchar* BOXES_WIZARD_SOURCE_page_names[2] = {"main-page", "url-page"};
extern const gchar* BOXES_INSTALLED_MEDIA_supported_extensions[16];

GType boxes_source_page_get_type (void) {
	static volatile gsize boxes_source_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_source_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_SOURCE_PAGE_MAIN, "BOXES_SOURCE_PAGE_MAIN", "main"}, {BOXES_SOURCE_PAGE_URL, "BOXES_SOURCE_PAGE_URL", "url"}, {BOXES_SOURCE_PAGE_LAST, "BOXES_SOURCE_PAGE_LAST", "last"}, {0, NULL, NULL}};
		GType boxes_source_page_type_id;
		boxes_source_page_type_id = g_enum_register_static ("BoxesSourcePage", values);
		g_once_init_leave (&boxes_source_page_type_id__volatile, boxes_source_page_type_id);
	}
	return boxes_source_page_type_id__volatile;
}


static void __lambda86_ (BoxesWizardScrolled* self) {
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_queue_resize ((GtkWidget*) self);
#line 428 "wizard-source.c"
}


static void ___lambda86__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__lambda86_ ((BoxesWizardScrolled*) self);
#line 435 "wizard-source.c"
}


static void __lambda87_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_ = NULL;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_add_class (_tmp0_, "boxes-menu-scrolled");
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 447 "wizard-source.c"
}


static void ___lambda87__gtk_widget_show (GtkWidget* _sender, gpointer self) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__lambda87_ ((BoxesWizardScrolled*) self);
#line 454 "wizard-source.c"
}


static void __lambda88_ (BoxesWizardScrolled* self) {
	GtkStyleContext* _tmp0_ = NULL;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = gtk_widget_get_style_context ((GtkWidget*) self);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_style_context_remove_class (_tmp0_, "boxes-menu-scrolled");
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_reset_style ((GtkWidget*) self);
#line 466 "wizard-source.c"
}


static void ___lambda88__gtk_widget_hide (GtkWidget* _sender, gpointer self) {
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__lambda88_ ((BoxesWizardScrolled*) self);
#line 473 "wizard-source.c"
}


void boxes_wizard_scrolled_setup (BoxesWizardScrolled* self, gint num_visible) {
	gint _tmp0_ = 0;
	GtkWidget* _tmp1_ = NULL;
	GtkWidget* _tmp2_ = NULL;
#line 23 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = num_visible;
#line 24 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->num_visible = _tmp0_;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object ((GObject*) self, "notify::num-visible", (GCallback) ___lambda86__g_object_notify, self, 0);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp1_, "show", (GCallback) ___lambda87__gtk_widget_show, self, 0);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_scrolled_window_get_vscrollbar ((GtkScrolledWindow*) self);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_object (_tmp2_, "hide", (GCallback) ___lambda88__gtk_widget_hide, self, 0);
#line 497 "wizard-source.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return self ? g_object_ref (self) : NULL;
#line 504 "wizard-source.c"
}


static void boxes_wizard_scrolled_real_get_preferred_height (GtkWidget* base, gint* minimum_height, gint* natural_height) {
	BoxesWizardScrolled * self;
	gint _vala_minimum_height = 0;
	gint _vala_natural_height = 0;
	gint _tmp0_ = 0;
	gint _tmp1_ = 0;
	GtkViewport* viewport = NULL;
	GtkWidget* _tmp2_ = NULL;
	GtkViewport* _tmp3_ = NULL;
	GtkBox* box = NULL;
	GtkViewport* _tmp4_ = NULL;
	GtkWidget* _tmp5_ = NULL;
	GtkBox* _tmp6_ = NULL;
	gint height = 0;
	gint i = 0;
	GtkBox* _tmp7_ = NULL;
	GList* _tmp8_ = NULL;
	gint _tmp18_ = 0;
	gint _tmp19_ = 0;
	gint _tmp20_ = 0;
	gint _tmp21_ = 0;
	gint _tmp22_ = 0;
	gint _tmp23_ = 0;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) base;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	GTK_WIDGET_CLASS (boxes_wizard_scrolled_parent_class)->get_preferred_height ((GtkWidget*) G_TYPE_CHECK_INSTANCE_CAST (self, GTK_TYPE_SCROLLED_WINDOW, GtkScrolledWindow), &_tmp0_, &_tmp1_);
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp0_;
#line 40 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp1_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = gtk_bin_get_child ((GtkBin*) self);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GTK_TYPE_VIEWPORT) ? ((GtkViewport*) _tmp2_) : NULL);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	viewport = _tmp3_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = viewport;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = gtk_bin_get_child ((GtkBin*) _tmp4_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GTK_TYPE_BOX) ? ((GtkBox*) _tmp5_) : NULL);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	box = _tmp6_;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	height = 0;
#line 45 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	i = 0;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = box;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = gtk_container_get_children ((GtkContainer*) _tmp7_);
#line 561 "wizard-source.c"
	{
		GList* w_collection = NULL;
		GList* w_it = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		w_collection = _tmp8_;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (w_it = w_collection; w_it != NULL; w_it = w_it->next) {
#line 569 "wizard-source.c"
			GtkWidget* w = NULL;
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			w = (GtkWidget*) w_it->data;
#line 573 "wizard-source.c"
			{
				GtkWidget* _tmp9_ = NULL;
				gboolean _tmp10_ = FALSE;
				gint child_height = 0;
				GtkWidget* _tmp11_ = NULL;
				gint _tmp12_ = 0;
				gint _tmp13_ = 0;
				gint _tmp14_ = 0;
				gint _tmp15_ = 0;
				gint _tmp16_ = 0;
				gint _tmp17_ = 0;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp9_ = w;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp10_ = gtk_widget_get_visible (_tmp9_);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (!_tmp10_) {
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					continue;
#line 593 "wizard-source.c"
				}
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp11_ = w;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				gtk_widget_get_preferred_height (_tmp11_, NULL, &_tmp12_);
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				child_height = _tmp12_;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp13_ = height;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp14_ = child_height;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				height = _tmp13_ + _tmp14_;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp15_ = i;
#line 52 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				i = _tmp15_ + 1;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp16_ = i;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp17_ = self->priv->num_visible;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (_tmp16_ == _tmp17_) {
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					break;
#line 619 "wizard-source.c"
				}
			}
		}
#line 46 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (w_collection);
#line 625 "wizard-source.c"
	}
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = _vala_minimum_height;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = height;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp20_ = MAX (_tmp18_, _tmp19_);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_minimum_height = _tmp20_;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp21_ = _vala_natural_height;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp22_ = height;
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp23_ = MAX (_tmp21_, _tmp22_);
#line 57 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_vala_natural_height = _tmp23_;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (box);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (viewport);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (minimum_height) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		*minimum_height = _vala_minimum_height;
#line 651 "wizard-source.c"
	}
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (natural_height) {
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		*natural_height = _vala_natural_height;
#line 657 "wizard-source.c"
	}
}


BoxesWizardScrolled* boxes_wizard_scrolled_construct (GType object_type) {
	BoxesWizardScrolled * self = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardScrolled*) g_object_new (object_type, NULL);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return self;
#line 668 "wizard-source.c"
}


BoxesWizardScrolled* boxes_wizard_scrolled_new (void) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_scrolled_construct (BOXES_TYPE_WIZARD_SCROLLED);
#line 675 "wizard-source.c"
}


static void boxes_wizard_scrolled_class_init (BoxesWizardScrolledClass * klass) {
	gint BoxesWizardScrolled_private_offset;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_parent_class = g_type_class_peek_parent (klass);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardScrolledPrivate));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	GTK_WIDGET_CLASS (klass)->get_preferred_height = boxes_wizard_scrolled_real_get_preferred_height;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_scrolled_finalize;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	BoxesWizardScrolled_private_offset = g_type_class_get_instance_private_offset (klass);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-scrolled.ui");
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "vbox", FALSE, G_STRUCT_OFFSET (BoxesWizardScrolled, vbox));
#line 695 "wizard-source.c"
}


static void boxes_wizard_scrolled_instance_init (BoxesWizardScrolled * self) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SCROLLED_GET_PRIVATE (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 704 "wizard-source.c"
}


static void boxes_wizard_scrolled_finalize (GObject* obj) {
	BoxesWizardScrolled * self;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SCROLLED, BoxesWizardScrolled);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->vbox);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_scrolled_parent_class)->finalize (obj);
#line 716 "wizard-source.c"
}


GType boxes_wizard_scrolled_get_type (void) {
	static volatile gsize boxes_wizard_scrolled_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_scrolled_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardScrolledClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_scrolled_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardScrolled), 0, (GInstanceInitFunc) boxes_wizard_scrolled_instance_init, NULL };
		GType boxes_wizard_scrolled_type_id;
		boxes_wizard_scrolled_type_id = g_type_register_static (GTK_TYPE_SCROLLED_WINDOW, "BoxesWizardScrolled", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_scrolled_type_id__volatile, boxes_wizard_scrolled_type_id);
	}
	return boxes_wizard_scrolled_type_id__volatile;
}


BoxesWizardMediaEntry* boxes_wizard_media_entry_construct (GType object_type, BoxesInstallerMedia* media) {
	BoxesWizardMediaEntry * self = NULL;
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	BoxesInstallerMedia* _tmp2_ = NULL;
	OsinfoOs* _tmp3_ = NULL;
	GtkLabel* _tmp7_ = NULL;
	BoxesInstallerMedia* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	gboolean _tmp10_ = FALSE;
	BoxesInstallerMedia* _tmp11_ = NULL;
	OsinfoMedia* _tmp12_ = NULL;
	BoxesInstallerMedia* _tmp28_ = NULL;
	OsinfoMedia* _tmp29_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (media != NULL, NULL);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardMediaEntry*) g_object_new (object_type, NULL);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->media = _tmp1_;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = media;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_->os;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ != NULL) {
#line 764 "wizard-source.c"
		GtkImage* _tmp4_ = NULL;
		BoxesInstallerMedia* _tmp5_ = NULL;
		OsinfoOs* _tmp6_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = self->priv->media_image;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = media;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = _tmp5_->os;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_downloader_fetch_os_logo (_tmp4_, _tmp6_, 64, NULL, NULL);
#line 776 "wizard-source.c"
	}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = self->priv->title_label;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = media;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = _tmp8_->label;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_tmp7_, _tmp9_);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = media;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp12_ = _tmp11_->os_media;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp12_ != NULL) {
#line 792 "wizard-source.c"
		BoxesInstallerMedia* _tmp13_ = NULL;
		OsinfoMedia* _tmp14_ = NULL;
		gboolean _tmp15_ = FALSE;
		gboolean _tmp16_ = FALSE;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp13_ = media;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp14_ = _tmp13_->os_media;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp14_, "live", &_tmp15_, NULL);
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp16_ = _tmp15_;
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = _tmp16_;
#line 807 "wizard-source.c"
	} else {
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp10_ = FALSE;
#line 811 "wizard-source.c"
	}
#line 79 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp10_) {
#line 815 "wizard-source.c"
		GtkLabel* _tmp17_ = NULL;
		GtkLabel* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		const gchar* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_ = NULL;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp17_ = self->priv->title_label;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp18_ = self->priv->title_label;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp19_ = gtk_label_get_label (_tmp18_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp20_ = _tmp19_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp21_ = _ ("Live");
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = g_strconcat (" (", _tmp21_, NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp23_ = _tmp22_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp24_ = g_strconcat (_tmp23_, ")", NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp25_ = _tmp24_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp26_ = g_strconcat (_tmp20_, _tmp25_, NULL);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp27_ = _tmp26_;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_label_set_label (_tmp18_, _tmp27_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp27_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp25_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp23_);
#line 857 "wizard-source.c"
	}
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp28_ = media;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp29_ = _tmp28_->os_media;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp29_ != NULL) {
#line 865 "wizard-source.c"
		const gchar* _tmp30_ = NULL;
		gboolean _tmp31_ = FALSE;
		BoxesInstallerMedia* _tmp32_ = NULL;
		OsinfoMedia* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		gchar* _tmp35_ = NULL;
		gchar* _tmp36_ = NULL;
		gboolean _tmp37_ = FALSE;
		gchar* architecture = NULL;
		gchar* _tmp45_ = NULL;
		GtkLabel* _tmp46_ = NULL;
		const gchar* _tmp47_ = NULL;
		BoxesInstallerMedia* _tmp48_ = NULL;
		OsinfoOs* _tmp49_ = NULL;
		const gchar* _tmp50_ = NULL;
		const gchar* _tmp51_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp32_ = media;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp33_ = _tmp32_->os_media;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_get (_tmp33_, "architecture", &_tmp34_, NULL);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp35_ = _tmp34_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp36_ = _tmp35_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp37_ = g_strcmp0 (_tmp36_, "i386") == 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp36_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_tmp37_) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp31_ = TRUE;
#line 900 "wizard-source.c"
		} else {
			BoxesInstallerMedia* _tmp38_ = NULL;
			OsinfoMedia* _tmp39_ = NULL;
			gchar* _tmp40_ = NULL;
			gchar* _tmp41_ = NULL;
			gchar* _tmp42_ = NULL;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp38_ = media;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp39_ = _tmp38_->os_media;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			g_object_get (_tmp39_, "architecture", &_tmp40_, NULL);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp41_ = _tmp40_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp42_ = _tmp41_;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp31_ = g_strcmp0 (_tmp42_, "i686") == 0;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp42_);
#line 921 "wizard-source.c"
		}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_tmp31_) {
#line 925 "wizard-source.c"
			const gchar* _tmp43_ = NULL;
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp43_ = _ ("32-bit x86 system");
#line 86 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = _tmp43_;
#line 931 "wizard-source.c"
		} else {
			const gchar* _tmp44_ = NULL;
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp44_ = _ ("64-bit x86 system");
#line 87 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp30_ = _tmp44_;
#line 938 "wizard-source.c"
		}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp45_ = g_strdup (_tmp30_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		architecture = _tmp45_;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp46_ = self->priv->details_label;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp47_ = architecture;
#line 88 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_label_set_label (_tmp46_, _tmp47_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp48_ = media;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp49_ = _tmp48_->os;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp50_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp49_);
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp51_ = _tmp50_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_tmp51_ != NULL) {
#line 960 "wizard-source.c"
			GtkLabel* _tmp52_ = NULL;
			GtkLabel* _tmp53_ = NULL;
			const gchar* _tmp54_ = NULL;
			const gchar* _tmp55_ = NULL;
			const gchar* _tmp56_ = NULL;
			BoxesInstallerMedia* _tmp57_ = NULL;
			OsinfoOs* _tmp58_ = NULL;
			const gchar* _tmp59_ = NULL;
			const gchar* _tmp60_ = NULL;
			gchar* _tmp61_ = NULL;
			gchar* _tmp62_ = NULL;
			gchar* _tmp63_ = NULL;
			gchar* _tmp64_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp52_ = self->priv->details_label;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp53_ = self->priv->details_label;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp54_ = gtk_label_get_label (_tmp53_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp55_ = _tmp54_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp56_ = _ (" from %s");
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp57_ = media;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp58_ = _tmp57_->os;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp59_ = osinfo_product_get_vendor ((OsinfoProduct*) _tmp58_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp60_ = _tmp59_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp61_ = g_strdup_printf (_tmp56_, _tmp60_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp62_ = _tmp61_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp63_ = g_strconcat (_tmp55_, _tmp62_, NULL);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp64_ = _tmp63_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			gtk_label_set_label (_tmp53_, _tmp64_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp64_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_g_free0 (_tmp62_);
#line 1006 "wizard-source.c"
		}
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (architecture);
#line 1010 "wizard-source.c"
	}
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return self;
#line 1014 "wizard-source.c"
}


BoxesWizardMediaEntry* boxes_wizard_media_entry_new (BoxesInstallerMedia* media) {
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_media_entry_construct (BOXES_TYPE_WIZARD_MEDIA_ENTRY, media);
#line 1021 "wizard-source.c"
}


static void boxes_wizard_media_entry_class_init (BoxesWizardMediaEntryClass * klass) {
	gint BoxesWizardMediaEntry_private_offset;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_media_entry_parent_class = g_type_class_peek_parent (klass);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardMediaEntryPrivate));
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_media_entry_finalize;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	BoxesWizardMediaEntry_private_offset = g_type_class_get_instance_private_offset (klass);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-media-entry.ui");
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "media_image", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, media_image));
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_label", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, title_label));
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "details_label", FALSE, BoxesWizardMediaEntry_private_offset + G_STRUCT_OFFSET (BoxesWizardMediaEntryPrivate, details_label));
#line 1043 "wizard-source.c"
}


static void boxes_wizard_media_entry_instance_init (BoxesWizardMediaEntry * self) {
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_MEDIA_ENTRY_GET_PRIVATE (self);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1052 "wizard-source.c"
}


static void boxes_wizard_media_entry_finalize (GObject* obj) {
	BoxesWizardMediaEntry * self;
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_MEDIA_ENTRY, BoxesWizardMediaEntry);
#line 63 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_image);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->title_label);
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->details_label);
#line 62 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_media_entry_parent_class)->finalize (obj);
#line 1070 "wizard-source.c"
}


GType boxes_wizard_media_entry_get_type (void) {
	static volatile gsize boxes_wizard_media_entry_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_media_entry_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardMediaEntryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_media_entry_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardMediaEntry), 0, (GInstanceInitFunc) boxes_wizard_media_entry_instance_init, NULL };
		GType boxes_wizard_media_entry_type_id;
		boxes_wizard_media_entry_type_id = g_type_register_static (GTK_TYPE_BUTTON, "BoxesWizardMediaEntry", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_media_entry_type_id__volatile, boxes_wizard_media_entry_type_id);
	}
	return boxes_wizard_media_entry_type_id__volatile;
}


void boxes_wizard_source_cleanup (BoxesWizardSource* self) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_install_media (self, NULL);
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->libvirt_sys_import = FALSE;
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, NULL);
#line 177 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_uri (self, "");
#line 1097 "wizard-source.c"
}


static void boxes_wizard_source_on_enter_url_button_clicked (BoxesWizardSource* self) {
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_URL);
#line 1106 "wizard-source.c"
}


static void _boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_enter_url_button_clicked ((BoxesWizardSource*) self);
#line 1113 "wizard-source.c"
}


static void boxes_wizard_source_on_url_back_button_clicked (BoxesWizardSource* self) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 187 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, NULL);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_page (self, BOXES_SOURCE_PAGE_MAIN);
#line 1124 "wizard-source.c"
}


static void _boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_url_back_button_clicked ((BoxesWizardSource*) self);
#line 1131 "wizard-source.c"
}


void boxes_wizard_source_update_url_page (BoxesWizardSource* self, const gchar* title, const gchar* text, const gchar* icon_name) {
	GtkLabel* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	const gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	GtkImage* _tmp9_ = NULL;
	const gchar* _tmp10_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (title != NULL);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (text != NULL);
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (icon_name != NULL);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->url_description_label;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = title;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = g_strconcat ("<b>", _tmp1_, NULL);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _tmp2_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = g_strconcat (_tmp3_, "</b>\n\n", NULL);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = _tmp4_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = text;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = g_strconcat (_tmp5_, _tmp6_, NULL);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = _tmp7_;
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_markup (_tmp0_, _tmp8_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp8_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp5_);
#line 192 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_tmp3_);
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = self->priv->url_image;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = icon_name;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_set (_tmp9_, "icon-name", _tmp10_, NULL);
#line 1187 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_data_free (gpointer _data) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	_data_ = _data;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data_->self);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_slice_free (BoxesWizardSourceAddMediaEntriesData, _data_);
#line 1198 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
	BoxesWizardSource* _tmp0_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = g_slice_new0 (BoxesWizardSourceAddMediaEntriesData);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_source_add_media_entries);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_source_add_media_entries_data_free);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->self = _tmp0_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 1217 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1225 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entries_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceAddMediaEntriesData* _data_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = _user_data_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_source_object_ = source_object;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_res_ = _res_;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries_co (_data_);
#line 1239 "wizard-source.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1246 "wizard-source.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_list_free (self);
#line 1255 "wizard-source.c"
}


static gboolean boxes_wizard_source_add_media_entries_co (BoxesWizardSourceAddMediaEntriesData* _data_) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (_data_->_state_) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case 0:
#line 1264 "wizard-source.c"
		goto _state_0;
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case 1:
#line 1268 "wizard-source.c"
		goto _state_1;
		default:
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_assert_not_reached ();
#line 1273 "wizard-source.c"
	}
	_state_0:
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp0_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp0_ = _data_->self->media_manager;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_state_ = 1;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_media_manager_list_installer_medias (_data_->_tmp0_, boxes_wizard_source_add_media_entries_ready, _data_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 1286 "wizard-source.c"
	_state_1:
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp1_ = NULL;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp1_ = boxes_media_manager_list_installer_medias_finish (_data_->_tmp0_, _data_->_res_);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->medias = _data_->_tmp1_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp2_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp2_ = _data_->self->priv->media_vbox;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp3_ = NULL;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp3_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp2_);
#line 1302 "wizard-source.c"
	{
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->child_collection = _data_->_tmp3_;
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (_data_->child_it = _data_->child_collection; _data_->child_it != NULL; _data_->child_it = _data_->child_it->next) {
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->child = (GtkWidget*) _data_->child_it->data;
#line 1310 "wizard-source.c"
			{
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp4_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp4_ = _data_->child;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp5_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp5_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp4_, BOXES_TYPE_WIZARD_MEDIA_ENTRY) ? ((BoxesWizardMediaEntry*) _data_->_tmp4_) : NULL)->media;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp6_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp6_ = _g_object_ref0 (_data_->_tmp5_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->child_media = _data_->_tmp6_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->obsolete = TRUE;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp7_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp7_ = _data_->medias;
#line 1332 "wizard-source.c"
				{
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->media_collection = _data_->_tmp7_;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					for (_data_->media_it = _data_->media_collection; _data_->media_it != NULL; _data_->media_it = _data_->media_it->next) {
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->_tmp8_ = NULL;
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->_tmp8_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->media_it->data);
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->media = _data_->_tmp8_;
#line 1344 "wizard-source.c"
						{
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp9_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp9_ = _data_->child_media;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp10_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp10_ = _data_->_tmp9_->device_file;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp11_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp11_ = _data_->media;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp12_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp12_ = _data_->_tmp11_->device_file;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							if (g_strcmp0 (_data_->_tmp10_, _data_->_tmp12_) == 0) {
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->obsolete = FALSE;
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_g_object_unref0 (_data_->media);
#line 207 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								break;
#line 1370 "wizard-source.c"
							}
#line 203 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_g_object_unref0 (_data_->media);
#line 1374 "wizard-source.c"
						}
					}
				}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp13_ = FALSE;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp13_ = _data_->obsolete;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp13_) {
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp14_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp14_ = _data_->self->priv->media_vbox;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp15_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp15_ = _data_->child;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					gtk_container_remove ((GtkContainer*) _data_->_tmp14_, _data_->_tmp15_);
#line 1394 "wizard-source.c"
				}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_data_->child_media);
#line 1398 "wizard-source.c"
			}
		}
#line 199 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_list_free0 (_data_->child_collection);
#line 1403 "wizard-source.c"
	}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp16_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp16_ = _data_->medias;
#line 1409 "wizard-source.c"
	{
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_vala1_media_collection = _data_->_tmp16_;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (_data_->_vala1_media_it = _data_->_vala1_media_collection; _data_->_vala1_media_it != NULL; _data_->_vala1_media_it = _data_->_vala1_media_it->next) {
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->_tmp17_ = NULL;
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->_tmp17_ = _g_object_ref0 ((BoxesInstallerMedia*) _data_->_vala1_media_it->data);
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_data_->_vala1_media = _data_->_tmp17_;
#line 1421 "wizard-source.c"
			{
#line 215 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->nouveau = TRUE;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp18_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp18_ = _data_->self->priv->media_vbox;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp19_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp19_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp18_);
#line 1433 "wizard-source.c"
				{
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_vala1_child_collection = _data_->_tmp19_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					for (_data_->_vala1_child_it = _data_->_vala1_child_collection; _data_->_vala1_child_it != NULL; _data_->_vala1_child_it = _data_->_vala1_child_it->next) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
						_data_->_vala1_child = (GtkWidget*) _data_->_vala1_child_it->data;
#line 1441 "wizard-source.c"
						{
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp20_ = NULL;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp20_ = _data_->_vala1_child;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp21_ = NULL;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp21_ = (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp20_, BOXES_TYPE_WIZARD_MEDIA_ENTRY) ? ((BoxesWizardMediaEntry*) _data_->_tmp20_) : NULL)->media;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp22_ = NULL;
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp22_ = _g_object_ref0 (_data_->_tmp21_);
#line 217 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_vala1_child_media = _data_->_tmp22_;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp23_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp23_ = _data_->_vala1_child_media;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp24_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp24_ = _data_->_tmp23_->device_file;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp25_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp25_ = _data_->_vala1_media;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp26_ = NULL;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_data_->_tmp26_ = _data_->_tmp25_->device_file;
#line 218 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							if (g_strcmp0 (_data_->_tmp24_, _data_->_tmp26_) == 0) {
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_data_->nouveau = FALSE;
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								_g_object_unref0 (_data_->_vala1_child_media);
#line 221 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
								break;
#line 1481 "wizard-source.c"
							}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
							_g_object_unref0 (_data_->_vala1_child_media);
#line 1485 "wizard-source.c"
						}
					}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_g_list_free0 (_data_->_vala1_child_collection);
#line 1490 "wizard-source.c"
				}
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp27_ = FALSE;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_data_->_tmp27_ = _data_->nouveau;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				if (_data_->_tmp27_) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp28_ = NULL;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					_data_->_tmp28_ = _data_->_vala1_media;
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
					boxes_wizard_source_add_media_entry (_data_->self, _data_->_tmp28_);
#line 1504 "wizard-source.c"
				}
#line 214 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_g_object_unref0 (_data_->_vala1_media);
#line 1508 "wizard-source.c"
			}
		}
	}
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp29_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp29_ = _data_->self->priv->media_vbox;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp30_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp30_ = gtk_container_get_children ((GtkContainer*) _data_->_tmp29_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp31_ = NULL;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp31_ = _data_->_tmp30_;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp32_ = 0U;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp32_ = g_list_length (_data_->_tmp31_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp33_ = FALSE;
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp33_ = _data_->_tmp32_ == ((guint) 0);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_list_free0 (_data_->_tmp31_);
#line 230 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_data_->_tmp33_) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp34_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp34_ = _data_->self->priv->media_scrolled;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_widget_hide ((GtkWidget*) _data_->_tmp34_);
#line 1542 "wizard-source.c"
	}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__g_list_free__g_object_unref0_0 (_data_->medias);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_data_->_state_ == 0) {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1550 "wizard-source.c"
	} else {
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1554 "wizard-source.c"
	}
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_unref (_data_->_async_result);
#line 196 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 1560 "wizard-source.c"
}


static Block69Data* block69_data_ref (Block69Data* _data69_) {
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_atomic_int_inc (&_data69_->_ref_count_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return _data69_;
#line 1569 "wizard-source.c"
}


static void block69_data_unref (void * _userdata_) {
	Block69Data* _data69_;
	_data69_ = (Block69Data*) _userdata_;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (g_atomic_int_dec_and_test (&_data69_->_ref_count_)) {
#line 1578 "wizard-source.c"
		BoxesWizardSource* self;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		self = _data69_->self;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data69_->entry);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data69_->media);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (self);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_slice_free (Block69Data, _data69_);
#line 1590 "wizard-source.c"
	}
}


static void __lambda89_ (Block69Data* _data69_) {
	BoxesWizardSource* self;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = _data69_->self;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _data69_->media;
#line 238 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_media_selected (self, _tmp0_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _data69_->entry);
#line 1606 "wizard-source.c"
}


static void ___lambda89__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	__lambda89_ (self);
#line 1613 "wizard-source.c"
}


static void boxes_wizard_source_add_media_entry (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	Block69Data* _data69_;
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
	BoxesInstallerMedia* _tmp2_ = NULL;
	BoxesWizardMediaEntry* _tmp3_ = NULL;
	GtkBox* _tmp4_ = NULL;
	BoxesWizardScrolled* _tmp5_ = NULL;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data69_ = g_slice_new0 (Block69Data);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data69_->_ref_count_ = 1;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data69_->self = g_object_ref (self);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = media;
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data69_->media);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data69_->media = _tmp1_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _data69_->media;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = boxes_wizard_media_entry_new (_tmp2_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp3_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data69_->entry = _tmp3_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->media_vbox;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_container_add ((GtkContainer*) _tmp4_, (GtkWidget*) _data69_->entry);
#line 237 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_connect_data ((GtkButton*) _data69_->entry, "clicked", (GCallback) ___lambda89__gtk_button_clicked, block69_data_ref (_data69_), (GClosureNotify) block69_data_unref, 0);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = self->priv->media_scrolled;
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show ((GtkWidget*) _tmp5_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	block69_data_unref (_data69_);
#line 234 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data69_ = NULL;
#line 1665 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free (gpointer _data) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
	_data_ = _data;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_data_->self);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_slice_free (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData, _data_);
#line 1676 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility (BoxesWizardSource* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
	BoxesWizardSource* _tmp0_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = g_slice_new0 (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_wizard_source_update_libvirt_sytem_entry_visibility);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_wizard_source_update_libvirt_sytem_entry_visibility_data_free);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->self = _tmp0_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (_data_);
#line 1695 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_finish (BoxesWizardSource* self, GAsyncResult* _res_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1703 "wizard-source.c"
}


static void boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_ = _user_data_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_source_object_ = source_object;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_res_ = _res_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (_data_);
#line 1717 "wizard-source.c"
}


static gboolean boxes_wizard_source_update_libvirt_sytem_entry_visibility_co (BoxesWizardSourceUpdateLibvirtSytemEntryVisibilityData* _data_) {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (_data_->_state_) {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case 0:
#line 1726 "wizard-source.c"
		goto _state_0;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case 1:
#line 1730 "wizard-source.c"
		goto _state_1;
		default:
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_assert_not_reached ();
#line 1735 "wizard-source.c"
	}
	_state_0:
	{
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_state_ = 1;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_libvirt_system_importer_new (boxes_wizard_source_update_libvirt_sytem_entry_visibility_ready, _data_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 1745 "wizard-source.c"
		_state_1:
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp1_ = NULL;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp1_ = boxes_libvirt_system_importer_new_finish (_data_->_res_, &_data_->_inner_error_);
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp0_ = _data_->_tmp1_;
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1755 "wizard-source.c"
			goto __catch109_g_error;
		}
#line 248 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_libvirt_sys_importer (_data_->self, _data_->_tmp0_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_data_->_tmp0_);
#line 1762 "wizard-source.c"
	}
	goto __finally109;
	__catch109_g_error:
	{
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_inner_error_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp2_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp2_ = _data_->_error_;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp3_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_data_->_tmp3_ = _data_->_tmp2_->message;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_debug ("wizard-source.vala:250: %s", _data_->_tmp3_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_data_->_error_);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (_data_->_state_ == 0) {
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1787 "wizard-source.c"
		} else {
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1791 "wizard-source.c"
		}
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_object_unref (_data_->_async_result);
#line 252 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 1797 "wizard-source.c"
	}
	__finally109:
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_data_->_inner_error_);
#line 247 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		return FALSE;
#line 1808 "wizard-source.c"
	}
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp4_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp4_ = _data_->self->priv->libvirt_sys_import_label;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp5_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp5_ = _data_->self->priv->_libvirt_sys_importer;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp6_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp6_ = boxes_libvirt_system_importer_get_wizard_menu_label (_data_->_tmp5_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp7_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp7_ = _data_->_tmp6_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp8_ = NULL;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp8_ = _data_->_tmp7_;
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_label_set_label (_data_->_tmp4_, _data_->_tmp8_);
#line 254 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_free0 (_data_->_tmp8_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp9_ = NULL;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_data_->_tmp9_ = _data_->self->priv->libvirt_sys_import_button;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_show_all ((GtkWidget*) _data_->_tmp9_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_data_->_state_ == 0) {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1844 "wizard-source.c"
	} else {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1848 "wizard-source.c"
	}
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_unref (_data_->_async_result);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return FALSE;
#line 1854 "wizard-source.c"
}


static void boxes_wizard_source_on_select_file_button_clicked (BoxesWizardSource* self) {
	GtkFileChooserDialog* dialog = NULL;
	const gchar* _tmp0_ = NULL;
	BoxesAppWindow* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GtkFileChooserDialog* _tmp4_ = NULL;
	GtkFileChooserDialog* _tmp5_ = NULL;
	GtkFileChooserDialog* _tmp6_ = NULL;
	GtkFileFilter* _tmp7_ = NULL;
	GtkFileFilter* _tmp8_ = NULL;
	GtkFileChooserDialog* _tmp9_ = NULL;
	GtkFileFilter* _tmp10_ = NULL;
	GtkFileFilter* _tmp11_ = NULL;
	GtkFileChooserDialog* _tmp18_ = NULL;
	gint _tmp19_ = 0;
	GtkFileChooserDialog* _tmp24_ = NULL;
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = _ ("Select a device or ISO file");
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = boxes_app_window;
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = _ ("_Cancel");
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = _ ("_Open");
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = (GtkFileChooserDialog*) gtk_file_chooser_dialog_new (_tmp0_, (GtkWindow*) _tmp1_, GTK_FILE_CHOOSER_ACTION_OPEN, _tmp2_, GTK_RESPONSE_CANCEL, _tmp3_, GTK_RESPONSE_ACCEPT, NULL);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp4_);
#line 260 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	dialog = _tmp4_;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = dialog;
#line 265 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_file_chooser_set_show_hidden ((GtkFileChooser*) _tmp5_, FALSE);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = dialog;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = gtk_file_filter_new ();
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_ref_sink (_tmp7_);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = _tmp7_;
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_file_chooser_set_filter ((GtkFileChooser*) _tmp6_, _tmp8_);
#line 266 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (_tmp8_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = dialog;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp10_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp9_);
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp11_ = _tmp10_;
#line 267 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_file_filter_add_mime_type (_tmp11_, "application/x-cd-image");
#line 1915 "wizard-source.c"
	{
		const gchar** extension_collection = NULL;
		gint extension_collection_length1 = 0;
		gint _extension_collection_size_ = 0;
		gint extension_it = 0;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		extension_collection = BOXES_INSTALLED_MEDIA_supported_extensions;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		extension_collection_length1 = G_N_ELEMENTS (BOXES_INSTALLED_MEDIA_supported_extensions);
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		for (extension_it = 0; extension_it < G_N_ELEMENTS (BOXES_INSTALLED_MEDIA_supported_extensions); extension_it = extension_it + 1) {
#line 1927 "wizard-source.c"
			const gchar* extension = NULL;
#line 268 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			extension = extension_collection[extension_it];
#line 1931 "wizard-source.c"
			{
				GtkFileChooserDialog* _tmp12_ = NULL;
				GtkFileFilter* _tmp13_ = NULL;
				GtkFileFilter* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
				gchar* _tmp16_ = NULL;
				gchar* _tmp17_ = NULL;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp12_ = dialog;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp13_ = gtk_file_chooser_get_filter ((GtkFileChooser*) _tmp12_);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp14_ = _tmp13_;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp15_ = extension;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp16_ = g_strconcat ("*", _tmp15_, NULL);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_tmp17_ = _tmp16_;
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				gtk_file_filter_add_pattern (_tmp14_, _tmp17_);
#line 269 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
				_g_free0 (_tmp17_);
#line 1955 "wizard-source.c"
			}
		}
	}
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp18_ = dialog;
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp19_ = gtk_dialog_run ((GtkDialog*) _tmp18_);
#line 270 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp19_ == ((gint) GTK_RESPONSE_ACCEPT)) {
#line 1965 "wizard-source.c"
		GtkFileChooserDialog* _tmp20_ = NULL;
		gchar* _tmp21_ = NULL;
		gchar* _tmp22_ = NULL;
		GtkButton* _tmp23_ = NULL;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp20_ = dialog;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp21_ = gtk_file_chooser_get_uri ((GtkFileChooser*) _tmp20_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp22_ = _tmp21_;
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, _tmp22_);
#line 271 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_free0 (_tmp22_);
#line 273 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, NULL);
#line 274 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_signal_emit_by_name (self, "activated");
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp23_ = self->priv->select_file_button;
#line 276 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp23_);
#line 1988 "wizard-source.c"
	}
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp24_ = dialog;
#line 279 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_destroy ((GtkWidget*) _tmp24_);
#line 259 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (dialog);
#line 1996 "wizard-source.c"
}


static void _boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_select_file_button_clicked ((BoxesWizardSource*) self);
#line 2003 "wizard-source.c"
}


static void boxes_wizard_source_on_libvirt_sys_import_button_clicked (BoxesWizardSource* self) {
	GtkButton* _tmp0_ = NULL;
#line 283 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 284 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->libvirt_sys_import = TRUE;
#line 285 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_emit_by_name (self, "activated");
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->libvirt_sys_import_button;
#line 287 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_set_selected (self, (GtkWidget*) _tmp0_);
#line 2019 "wizard-source.c"
}


static void _boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_on_libvirt_sys_import_button_clicked ((BoxesWizardSource*) self);
#line 2026 "wizard-source.c"
}


static void boxes_wizard_source_on_media_selected (BoxesWizardSource* self, BoxesInstallerMedia* media) {
	GError * _inner_error_ = NULL;
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 290 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (media != NULL);
#line 2036 "wizard-source.c"
	{
		BoxesInstallerMedia* _tmp0_ = NULL;
		BoxesMediaManager* _tmp1_ = NULL;
		BoxesInstallerMedia* _tmp2_ = NULL;
		BoxesInstallerMedia* _tmp3_ = NULL;
		BoxesInstallerMedia* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp1_ = self->media_manager;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = media;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp3_ = boxes_media_manager_create_installer_media_from_media (_tmp1_, _tmp2_, &_inner_error_);
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp0_ = _tmp3_;
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 2054 "wizard-source.c"
			goto __catch110_g_error;
		}
#line 292 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, _tmp0_);
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = media;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp5_ = _tmp4_->device_file;
#line 293 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, _tmp5_);
#line 294 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_signal_emit_by_name (self, "activated");
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_object_unref0 (_tmp0_);
#line 2069 "wizard-source.c"
	}
	goto __finally110;
	__catch110_g_error:
	{
		GError* _error_ = NULL;
		BoxesInstallerMedia* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		const gchar* _tmp9_ = NULL;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_error_ = _inner_error_;
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_inner_error_ = NULL;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp6_ = media;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp7_ = _tmp6_->device_file;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp8_ = _error_;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp9_ = _tmp8_->message;
#line 297 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_warning ("wizard-source.vala:297: Failed to setup installation media '%s': %s", _tmp7_, _tmp9_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_g_error_free0 (_error_);
#line 2095 "wizard-source.c"
	}
	__finally110:
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_clear_error (&_inner_error_);
#line 291 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		return;
#line 2106 "wizard-source.c"
	}
}


BoxesWizardSource* boxes_wizard_source_construct (GType object_type) {
	BoxesWizardSource * self = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = (BoxesWizardSource*) g_object_new (object_type, NULL);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return self;
#line 2117 "wizard-source.c"
}


BoxesWizardSource* boxes_wizard_source_new (void) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return boxes_wizard_source_construct (BOXES_TYPE_WIZARD_SOURCE);
#line 2124 "wizard-source.c"
}


GtkWidget* boxes_wizard_source_get_selected (BoxesWizardSource* self) {
	GtkWidget* result;
	GtkWidget* _tmp0_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_selected;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2139 "wizard-source.c"
}


void boxes_wizard_source_set_selected (BoxesWizardSource* self, GtkWidget* value) {
	GtkWidget* _tmp0_ = NULL;
	GtkWidget* _tmp1_ = NULL;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_selected);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->_selected = _tmp1_;
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "selected");
#line 2158 "wizard-source.c"
}


const gchar* boxes_wizard_source_get_uri (BoxesWizardSource* self) {
	const gchar* result;
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = gtk_entry_get_text (_tmp0_);
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp1_;
#line 103 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2176 "wizard-source.c"
}


void boxes_wizard_source_set_uri (BoxesWizardSource* self, const gchar* value) {
	GtkEntry* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->url_entry;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = value;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_entry_set_text (_tmp0_, _tmp1_);
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "uri");
#line 2193 "wizard-source.c"
}


BoxesInstallerMedia* boxes_wizard_source_get_install_media (BoxesWizardSource* self) {
	BoxesInstallerMedia* result;
	BoxesInstallerMedia* _tmp0_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_install_media;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2208 "wizard-source.c"
}


static void boxes_wizard_source_set_install_media (BoxesWizardSource* self, BoxesInstallerMedia* value) {
	BoxesInstallerMedia* _tmp0_ = NULL;
	BoxesInstallerMedia* _tmp1_ = NULL;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->_install_media = _tmp1_;
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "install-media");
#line 2227 "wizard-source.c"
}


BoxesLibvirtSystemImporter* boxes_wizard_source_get_libvirt_sys_importer (BoxesWizardSource* self) {
	BoxesLibvirtSystemImporter* result;
	BoxesLibvirtSystemImporter* _tmp0_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_libvirt_sys_importer;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2242 "wizard-source.c"
}


static void boxes_wizard_source_set_libvirt_sys_importer (BoxesWizardSource* self, BoxesLibvirtSystemImporter* value) {
	BoxesLibvirtSystemImporter* _tmp0_ = NULL;
	BoxesLibvirtSystemImporter* _tmp1_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_libvirt_sys_importer);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->_libvirt_sys_importer = _tmp1_;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "libvirt-sys-importer");
#line 2261 "wizard-source.c"
}


BoxesSourcePage boxes_wizard_source_get_page (BoxesWizardSource* self) {
	BoxesSourcePage result;
	BoxesSourcePage _tmp0_ = 0;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = self->priv->_page;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	result = _tmp0_;
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return result;
#line 2276 "wizard-source.c"
}


void boxes_wizard_source_set_page (BoxesWizardSource* self, BoxesSourcePage value) {
	BoxesSourcePage _tmp0_ = 0;
	BoxesSourcePage _tmp1_ = 0;
	const gchar* _tmp2_ = NULL;
	GtkWidget* _tmp3_ = NULL;
	BoxesSourcePage _tmp5_ = 0;
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_return_if_fail (self != NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = value;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->_page = _tmp0_;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = value;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp2_ = BOXES_WIZARD_SOURCE_page_names[_tmp1_];
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_stack_set_visible_child_name ((GtkStack*) self, _tmp2_);
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = self->priv->_selected;
#line 143 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ != NULL) {
#line 2302 "wizard-source.c"
		GtkWidget* _tmp4_ = NULL;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp4_ = self->priv->_selected;
#line 144 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		gtk_widget_grab_focus (_tmp4_);
#line 2308 "wizard-source.c"
	}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = value;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (_tmp5_) {
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_MAIN:
#line 2316 "wizard-source.c"
		{
			GtkBox* _tmp6_ = NULL;
#line 147 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp6_ = self->priv->main_vbox;
#line 149 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp6_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			break;
#line 2327 "wizard-source.c"
		}
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_SOURCE_PAGE_URL:
#line 2331 "wizard-source.c"
		{
			GtkEntry* _tmp7_ = NULL;
			GtkEntry* _tmp8_ = NULL;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp7_ = self->url_entry;
#line 152 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			g_signal_emit_by_name ((GtkEditable*) _tmp7_, "changed");
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			_tmp8_ = self->url_entry;
#line 153 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			gtk_widget_grab_focus ((GtkWidget*) _tmp8_);
#line 154 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
			break;
#line 2345 "wizard-source.c"
		}
		default:
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 2350 "wizard-source.c"
	}
#line 138 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_notify ((GObject *) self, "page");
#line 2354 "wizard-source.c"
}


static GObject * boxes_wizard_source_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesWizardSource * self;
	BoxesMediaManager* _tmp0_ = NULL;
	GtkBox* _tmp1_ = NULL;
	gint _tmp2_ = 0;
	gint _tmp3_ = 0;
	gint num_visible = 0;
	BoxesWizardScrolled* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	BoxesWizardScrolled* _tmp6_ = NULL;
	GtkBox* _tmp7_ = NULL;
	GtkBox* _tmp8_ = NULL;
	GtkAlignment* _tmp9_ = NULL;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	parent_class = G_OBJECT_CLASS (boxes_wizard_source_parent_class);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp0_ = boxes_media_manager_get_instance ();
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media_manager);
#line 160 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->media_manager = _tmp0_;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp1_ = self->priv->main_vbox;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp1_);
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp3_ = gdk_screen_height ();
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	if (_tmp3_ > 800) {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = 5;
#line 2395 "wizard-source.c"
	} else {
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		_tmp2_ = 4;
#line 2399 "wizard-source.c"
	}
#line 163 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	num_visible = _tmp2_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp4_ = self->priv->media_scrolled;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp5_ = num_visible;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_scrolled_setup (_tmp4_, _tmp5_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp6_ = self->priv->media_scrolled;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp7_ = _tmp6_->vbox;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp8_ = _g_object_ref0 (_tmp7_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv->media_vbox = _tmp8_;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_tmp9_ = self->priv->url_entry_bin;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_draw_as_css_box ((GtkWidget*) _tmp9_);
#line 168 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_update_libvirt_sytem_entry_visibility (self, NULL, NULL);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_add_media_entries (self, NULL, NULL);
#line 170 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_stack_set_transition_type ((GtkStack*) self, GTK_STACK_TRANSITION_TYPE_SLIDE_LEFT_RIGHT);
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	return obj;
#line 2431 "wizard-source.c"
}


static void boxes_wizard_source_class_init (BoxesWizardSourceClass * klass) {
	gint BoxesWizardSource_private_offset;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	boxes_wizard_source_parent_class = g_type_class_peek_parent (klass);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_type_class_add_private (klass, sizeof (BoxesWizardSourcePrivate));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_wizard_source_get_property;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_wizard_source_set_property;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_wizard_source_constructor;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_wizard_source_finalize;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_SELECTED, g_param_spec_object ("selected", "selected", "selected", GTK_TYPE_WIDGET, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_URI, g_param_spec_string ("uri", "uri", "uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_INSTALL_MEDIA, g_param_spec_object ("install-media", "install-media", "install-media", BOXES_TYPE_INSTALLER_MEDIA, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER, g_param_spec_object ("libvirt-sys-importer", "libvirt-sys-importer", "libvirt-sys-importer", BOXES_TYPE_LIBVIRT_SYSTEM_IMPORTER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_WIZARD_SOURCE_PAGE, g_param_spec_enum ("page", "page", "page", BOXES_TYPE_SOURCE_PAGE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	BoxesWizardSource_private_offset = g_type_class_get_instance_private_offset (klass);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/wizard-source.ui");
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_signal_new ("activated", BOXES_TYPE_WIZARD_SOURCE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "main_vbox", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, main_vbox));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "media_scrolled", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, media_scrolled));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_description_label", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, url_description_label));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_image", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, url_image));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_entry_bin", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, url_entry_bin));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "url_entry", FALSE, G_STRUCT_OFFSET (BoxesWizardSource, url_entry));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "select_file_button", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, select_file_button));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "libvirt_sys_import_button", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, libvirt_sys_import_button));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "libvirt_sys_import_label", FALSE, BoxesWizardSource_private_offset + G_STRUCT_OFFSET (BoxesWizardSourcePrivate, libvirt_sys_import_label));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_enter_url_button_clicked", G_CALLBACK(_boxes_wizard_source_on_enter_url_button_clicked_gtk_button_clicked));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_url_back_button_clicked", G_CALLBACK(_boxes_wizard_source_on_url_back_button_clicked_gtk_button_clicked));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_select_file_button_clicked", G_CALLBACK(_boxes_wizard_source_on_select_file_button_clicked_gtk_button_clicked));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_libvirt_sys_import_button_clicked", G_CALLBACK(_boxes_wizard_source_on_libvirt_sys_import_button_clicked_gtk_button_clicked));
#line 2491 "wizard-source.c"
}


static void boxes_wizard_source_instance_init (BoxesWizardSource * self) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self->priv = BOXES_WIZARD_SOURCE_GET_PRIVATE (self);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	g_type_ensure (BOXES_TYPE_WIZARD_SCROLLED);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 2502 "wizard-source.c"
}


static void boxes_wizard_source_finalize (GObject* obj) {
	BoxesWizardSource * self;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 101 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_selected);
#line 106 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_install_media);
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->_libvirt_sys_importer);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->main_vbox);
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_scrolled);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_description_label);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_image);
#line 121 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->url_entry_bin);
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->url_entry);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->select_file_button);
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->libvirt_sys_import_button);
#line 129 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->libvirt_sys_import_label);
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->priv->media_vbox);
#line 133 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	_g_object_unref0 (self->media_manager);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	G_OBJECT_CLASS (boxes_wizard_source_parent_class)->finalize (obj);
#line 2540 "wizard-source.c"
}


GType boxes_wizard_source_get_type (void) {
	static volatile gsize boxes_wizard_source_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_wizard_source_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesWizardSourceClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_wizard_source_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesWizardSource), 0, (GInstanceInitFunc) boxes_wizard_source_instance_init, NULL };
		GType boxes_wizard_source_type_id;
		boxes_wizard_source_type_id = g_type_register_static (GTK_TYPE_STACK, "BoxesWizardSource", &g_define_type_info, 0);
		g_once_init_leave (&boxes_wizard_source_type_id__volatile, boxes_wizard_source_type_id);
	}
	return boxes_wizard_source_type_id__volatile;
}


static void _vala_boxes_wizard_source_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_selected (self));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_string (value, boxes_wizard_source_get_uri (self));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_install_media (self));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_object (value, boxes_wizard_source_get_libvirt_sys_importer (self));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		g_value_set_enum (value, boxes_wizard_source_get_page (self));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 2591 "wizard-source.c"
		default:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 2597 "wizard-source.c"
	}
}


static void _vala_boxes_wizard_source_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesWizardSource * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_WIZARD_SOURCE, BoxesWizardSource);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
	switch (property_id) {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_SELECTED:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_selected (self, g_value_get_object (value));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_URI:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_uri (self, g_value_get_string (value));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_INSTALL_MEDIA:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_install_media (self, g_value_get_object (value));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_LIBVIRT_SYS_IMPORTER:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_libvirt_sys_importer (self, g_value_get_object (value));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		case BOXES_WIZARD_SOURCE_PAGE:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		boxes_wizard_source_set_page (self, g_value_get_enum (value));
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 2637 "wizard-source.c"
		default:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/wizard-source.vala"
		break;
#line 2643 "wizard-source.c"
	}
}



